
/*
  gtkktoolkit.c: A toolkit built on top of the GTK++ to provide 
		 GUI interfaces.
  Copyright (c) 1999 C Hanish Menon
  hanishkvc@hotmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/
/* 

  Begin: 21 nov 1999

  CHANGELOG:

*/


#ifndef __GTKKTOOLKIT_C__
#define __GTKKTOOLKIT_C__

#define GTKK_MENU_SEPERATOR "_GTKK_MENU_SEPERATOR_"

// Function to create the Main menu entries.

void gtkk_menu_new(GtkMenuBar *MenuBarCur, void(*On_MenuItem_Activate)(), 
	gint iNoMenuItems, ...)
{
  va_list argptr;
  GtkWidget *MenuItemCur, *MenuCur;
  gint iMainMenuItemCur, iSubMenuItemCur, iSubMenuItemCount;
  gchar *sMenuItem;

  va_start(argptr,iNoMenuItems);
  
  for(iMainMenuItemCur = 0; iMainMenuItemCur < iNoMenuItems; iMainMenuItemCur++)
  {
    sMenuItem = va_arg(argptr,char*);
    MenuItemCur = gtk_menu_item_new_with_label(sMenuItem);
    gtk_menu_bar_append(GTK_MENU_BAR(MenuBarCur), MenuItemCur);
    gtk_widget_show(MenuItemCur);
    MenuCur = gtk_menu_new();
    gtk_menu_item_set_submenu(GTK_MENU_ITEM(MenuItemCur), MenuCur);
    gtk_widget_show(MenuCur);
    
    iSubMenuItemCount = va_arg(argptr,int);
    for(iSubMenuItemCur = 0; iSubMenuItemCur < iSubMenuItemCount; iSubMenuItemCur++)
    {
      sMenuItem = va_arg(argptr,char*);
      if(strcmp(sMenuItem,GTKK_MENU_SEPERATOR) != 0)
      {
        MenuItemCur = gtk_menu_item_new_with_label(sMenuItem);
        gtk_signal_connect(GTK_OBJECT(MenuItemCur), "activate",
          GTK_SIGNAL_FUNC(On_MenuItem_Activate),sMenuItem);
        gtk_menu_append(GTK_MENU(MenuCur), MenuItemCur);
        gtk_widget_show(MenuItemCur);
      }
      else
      {
        MenuItemCur = gtk_menu_item_new();
        gtk_menu_append(GTK_MENU(MenuCur), MenuItemCur);
        gtk_widget_show(MenuItemCur);
      }
    }
  }
  va_end(argptr);
}


// Functions for Tree
void gtkk_tree_append_subtree(GtkWidget *Tree, gchar *sSubTreeName,
  void (*On_TreeItem_Select)(),
  gchar **sSubTreeItems, gint iSubTreeItemCount)
{
  GtkWidget *SubTreeCur, *TreeItemCur;
  int iCurSubTreeItem;
  
  TreeItemCur = gtk_tree_item_new_with_label(sSubTreeName);
  gtk_tree_append(GTK_TREE(Tree), TreeItemCur);
  gtk_widget_show(TreeItemCur);
  
  if(sSubTreeItems != NULL)
  {
    SubTreeCur = gtk_tree_new();
    gtk_tree_item_set_subtree(GTK_TREE_ITEM(TreeItemCur), SubTreeCur);
   
    for(iCurSubTreeItem = 0; iCurSubTreeItem < iSubTreeItemCount; iCurSubTreeItem++)
    {
      g_print("%s\n",sSubTreeItems[iCurSubTreeItem]);
      TreeItemCur = gtk_tree_item_new_with_label(sSubTreeItems[iCurSubTreeItem]);
      gtk_signal_connect(GTK_OBJECT(TreeItemCur),"select",
//        GTK_SIGNAL_FUNC(On_TreeItem_Select),sSubTreeItems[iCurSubTreeItem]);
        GTK_SIGNAL_FUNC(On_TreeItem_Select),NULL);
      gtk_tree_append(GTK_TREE(SubTreeCur), TreeItemCur);
      gtk_widget_show(TreeItemCur);
    }
  }
}


// Functions for Dialogs

void gtkk_CloseDialog_ButtonClicked(GtkWidget *widget, gpointer data)
{
  gtk_widget_destroy(GTK_WIDGET(data));
}

int gtkk_ClosingDialog_DialogDestroy(GtkWidget *widget, gpointer data)
{
  gtk_grab_remove(GTK_WIDGET(widget));
  return FALSE; // Ok to release
}

void gtkk_message_box_show(gchar sMessage[])
{
  GtkWidget *DialogCur, *LabelCur, *ButtonOk;
  
  DialogCur = gtk_dialog_new();
  gtk_signal_connect(GTK_OBJECT(DialogCur),"destroy",
    GTK_SIGNAL_FUNC(gtkk_ClosingDialog_DialogDestroy),NULL);
  
  LabelCur = gtk_label_new(sMessage);
  gtk_misc_set_padding(GTK_MISC(LabelCur), 10, 10);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(DialogCur)->vbox),LabelCur,
    TRUE,TRUE,0);
  gtk_widget_show(LabelCur);
  
  ButtonOk = gtk_button_new_with_label("Ok");
  gtk_signal_connect(GTK_OBJECT(ButtonOk),"clicked",
    GTK_SIGNAL_FUNC(gtkk_CloseDialog_ButtonClicked),DialogCur);
  GTK_WIDGET_SET_FLAGS(ButtonOk, GTK_CAN_DEFAULT);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(DialogCur)->action_area),ButtonOk,
    TRUE,TRUE,0);
  gtk_widget_grab_default(ButtonOk);
  gtk_widget_show(ButtonOk);
  
  gtk_widget_show(DialogCur);
  gtk_grab_add(DialogCur);
}

gtkk_file_selection_show(gchar sTitle[], gchar sDefaultFile[],
	void(*On_OkButton_Clicked)())
{
  GtkWidget *FileSelectionCur;
  
  FileSelectionCur = gtk_file_selection_new(sTitle);
  if(sDefaultFile != NULL)
    gtk_file_selection_set_filename(GTK_FILE_SELECTION(FileSelectionCur),
      sDefaultFile);
  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(FileSelectionCur)->ok_button),
    "clicked", GTK_SIGNAL_FUNC(On_OkButton_Clicked),FileSelectionCur);
  gtk_signal_connect_object(
    GTK_OBJECT(GTK_FILE_SELECTION(FileSelectionCur)->ok_button),
    "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy),GTK_OBJECT(FileSelectionCur));
  gtk_signal_connect_object(
    GTK_OBJECT(GTK_FILE_SELECTION(FileSelectionCur)->cancel_button),
    "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy),GTK_OBJECT(FileSelectionCur));
  gtk_widget_show(FileSelectionCur);
}	
	
	
	
#endif
